@@ -209,9 +209,9 @@ class HandlebarsJSTemplateTagTest(TestCase, BaseJSTemplateTagTestMixin):
             res,
              '<script type="text/x-handlebars-template" id="testtemplate">'
              '<p>Mustache\'s template full of {{ foo }} and \\.</p>\n'
-             '</script><script>function(H) {var source = $("#testtemplate").html();'
+             '</script><script>(function(H) {var source = $("#testtemplate").html();'
              'H.templates = H.templates || {};'
-             'H.templates["testtemplate"] = H.compile(source);}(Handlebars);</script>')
+             'H.templates["testtemplate"] = H.compile(source);})(Handlebars);</script>')
 
 
     @override_settings(JSTEMPLATE_DIRS=[DIR])
@@ -224,8 +224,8 @@ class HandlebarsJSTemplateTagTest(TestCase, BaseJSTemplateTagTestMixin):
             res,
              '<script type="text/x-handlebars-template" id="testtemplate">'
              '<p>Mustache\'s template full of {{ foo }} and \\.</p>\n'
-             '</script><script>function(H) {var source = $("#testtemplate").html();'
-             'H.registerPartial("testtemplate", source);}(Handlebars);</script>')
+             '</script><script>(function(H) {var source = $("#testtemplate").html();'
+             'H.registerPartial("testtemplate", source);})(Handlebars);</script>')
 
 
 class DustTemplateTagTest(TestCase, BaseJSTemplateTagTestMixin):
